Program
    Uses
        svg,
        poxml,
        keyset

Var
    ms_start, ms, fm, cfps: Integer
    m: Real
    fd: Real = 1.0
    
Procedure SyncFramer()
Begin
    fm = Millisecs - ms
    ms = Millisecs
    fd = (fm / 1000.0) * 60.0
    fd = SmoothFrameDelta(fd) 
End

Function CalcFps(m1: Integer, m2: Integer) : Integer
Begin

    If ((m2 - m1) > 0) then
        result = (1000.0/(m2 - m1))
    Else
        result = 999
    Endif

End

Function SmoothFrameDelta(fd: Real) : Real ; export
Var
    avg, fd1, fd2, fd3, fd4, fd5, fd6, fd7, fd8, fd9: Static Real
Begin

    avg = (fd1 + fd2 + fd3 + fd4 + fd5 + fd6 + fd7 + fd8 + fd9 + fd) / 10.0 
    
    fd1 = fd2
    fd2 = fd3
    fd3 = fd4
    fd4 = fd5
    fd5 = fd6
    fd6 = fd7
    fd7 = fd8
    fd8 = fd9
    fd9 = fd
    
    If fd > avg then fd = avg
    result = fd

End

Procedure SeaweedUpdate(poly: ^svgPolygons, xoffset: Integer, divs: Integer, len: Integer)
Var
    i, offset: Integer
    x, y, t: Real    
Begin
    poly.totalPoints = divs*2
    For i = 0 to (divs-1)
		
        x = Sin( (i + (m/500) + (xoffset)) *divs*2)
        x = x * 10
        x = x * ((ToReal((i-divs))/divs))
        
        y = (i*len) - ((divs-1)*len)
        
        t = ToReal(i)/4
        If t < 0 then t = 1      
    
        SetPolyX(poly.points, i, x-t )
        SetPolyY(poly.points, i, y)
        
        offset = (2*divs)-1-i
        SetPolyX(poly.points, offset, x+t )
        SetPolyY(poly.points, offset, y)
        
    Next
    poly.updated = TRUE
End

Function RGBtoInt(r: Integer, g: Integer, b: Integer): Integer
Begin
    result = 0
    result = result + (r Shl 16)
    result = result + (g Shl 8)
    result = result + b
End

Const
    WEEDS = 18
    BUBBLES = 10

Var
    canvas, bg: Element
    
    seaweed: Array[WEEDS] of ^svgs
    seaweedPoly: Array[WEEDS] of ^svgPolygons
    seaweedLen: Array[WEEDS] of Integer
    
    shark: ^svgs
    sharkPoly: ^svgPolygons
    
    i: Integer

Begin
    
    SetAppName("Sea Demo")
    OpenScreen(640, 480, 32, FALSE, COB_SHOWBORDER)
    Randomize(Millisecs)
    VSync(1)

    svgQuality = 2
    
    bg = LoadImage('rsc\bg.jpg')
    
    canvas = CreateSprite(640, 480)
    SetFont("verdana", 8, 0, canvas)
    
    shark = LoadSvg('rsc\shark.svg')
    sharkPoly = GetPolygonById(shark, 'shark')
    SetSvgScale(shark, 0.3, 0.3)
    SetSvgPosition(shark, 640, 360)
    
    // Init Weeds
    For i = 0 to (WEEDS-1)
        seaweed[i] = LoadSvg('rsc\seaweed.svg')
        seaweedPoly[i] = GetPolygonById(seaweed[i], 'seaweed')
        SetSvgPosition(seaweed[i], 20 + (i*35), 480)
        seaweedLen[i] = Rand(3, 20)
        seaweedPoly[i].fill = RGBtoInt(29, Rand(140, 200), Rand(80, 120))
        seaweedPoly[i].fill2 = seaweedPoly[i].fill
        seaweedPoly[i].stroke = seaweedPoly[i].fill   
    Next    
    
    SyncFramer()
    While (KeyDown(VK_ESCAPE) = FALSE)
        SyncFramer()
    
        DrawImage(bg, 0, 0, canvas)
        
        m = Millisecs
        
        For i = 0 to (WEEDS-1)
            SeaweedUpdate(seaweedPoly[i], seaweed[i].x * 7, seaweedLen[i], 12)
        Next
        
        SetSvgPosition(shark, shark.x + (fd*-1), shark.y)
        If sharkPoly.maxx < 0 then SetSvgPosition(shark, 640, Rand(0, 400)) 
        
        
        RenderSvgs(canvas) 
        
        PenColor(ToRGBA(255,255,255), canvas)
        Text(10, 10, "FPS: "+cfps, canvas)
        PenColor(ToRGBA(255,255,255,200), canvas)
        Text(10, 25, "Real-time SVG Tech Demo", canvas)
        Text(10, 40, "Underwater demo", canvas)
        Text(10, 55, "2010-09-05", canvas)
        Text(10, 70, "tophatstuff.co.uk", canvas)
        PenColor(ToRGBA(255,255,255,160), canvas)
        Text(10, 85, "background: imageafter.com", canvas)
    
        Flip
        //Pause(1)
        cfps = CalcFps(ms, Millisecs)
    Wend

End